# Incomplete awlsim TODO list

## S7 compatibility

- Implement parsing of attributes
- Implement the remaining FUP block types

## core

- Blocks that are no longer linked to (created by) sources should be removed.
- Single download of symtab causes a redefinition error.
- Add a FBD (FUP) decompiler
- Add a LAD (KOP) (de-)compiler
- XML based .awlpro file format

## GUI

- Save window status (open MDI windows, positions, etc)
- Show UDTs in block tree
- Extend FBD (FUP) editor
- Add LAD (KOP) editor